(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6074,        204]*)
(*NotebookOutlinePosition[      6989,        232]*)
(*  CellTagsIndexPosition[      6945,        228]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DefCovD", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["DefTensor[",
    FontFamily->"Courier"],
  StyleBox["covd",
    FontSlant->"Italic"],
  "[",
  StyleBox["-a",
    FontSlant->"Italic"],
  "]",
  StyleBox[",",
    FontSlant->"Italic"],
  " {",
  StyleBox["post-string",
    FontSlant->"Italic"],
  ",",
  StyleBox[" pre-string",
    FontSlant->"Italic"],
  "}",
  StyleBox["]",
    FontFamily->"Courier"],
  " defines ",
  StyleBox["covd ",
    FontSlant->"Italic"],
  "to be a covariant derivative on the manifold associated to index ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and having output in ",
  StyleBox["StandardForm",
    FontFamily->"Courier"],
  " as given by the strings ",
  StyleBox["post-string",
    FontSlant->"Italic"],
  " in Postfix notation and ",
  StyleBox["pre-string",
    FontSlant->"Italic"],
  " in Prefix notation."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] Currently ",
  StyleBox["covd",
    FontSlant->"Italic"],
  " must be a valid ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " symbol, not in use in the present session with any other meaning.\n\
\[FilledSmallSquare] Options:\n",
  StyleBox[ButtonBox["Torsion",
    ButtonData:>{"Torsion.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t\t",
  StyleBox["False",
    FontFamily->"Courier"],
  "\t\t\t\twhether the connection has torsion\n",
  StyleBox[ButtonBox["Curvature",
    ButtonData:>{"Curvature.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t\t",
  StyleBox["True",
    FontFamily->"Courier"],
  "\t\t\t\twhether the connection has curvature\n",
  StyleBox[ButtonBox["FromMetric",
    ButtonData:>{"FromMetric.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t\t",
  StyleBox["Null",
    FontFamily->"Courier"],
  "\t\t\t\tmetric from which the connection derives\n",
  StyleBox[ButtonBox["CurvatureRelations",
    ButtonData:>{"CurvatureRelations.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t",
  StyleBox["True",
    FontFamily->"Courier"],
  "\t\t\t\twhether contracted Riemman is replaced\n",
  StyleBox[ButtonBox["OrthogonalTo",
    ButtonData:>{"OrthogonalTo.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t",
  StyleBox["{}",
    FontFamily->"Courier"],
  "\n",
  StyleBox[ButtonBox["ProjectedWith",
    ButtonData:>{"ProjectedWith.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t",
  StyleBox["{}",
    FontFamily->"Courier"],
  "\n\[FilledSmallSquare] Def-Options:\n",
  StyleBox[ButtonBox["DefInfo",
    ButtonData:>{"DefInfo.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t\t",
  StyleBox["{\"covd\", \"\"",
    FontFamily->"Courier"],
  "}\t\tinformation on the symbol\n",
  StyleBox[ButtonBox["Master",
    ButtonData:>{"Master.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t\t",
  StyleBox["None",
    FontFamily->"Courier"],
  "\t\t\t\tmaster of new symbol\n",
  StyleBox[ButtonBox["PrintAs",
    ButtonData:>{"PrintAs.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t\t\t",
  StyleBox["Identity",
    FontFamily->"Courier"],
  "\t\t\tstring or function of symbol for output\n",
  StyleBox[ButtonBox["ProtectNewSymbol",
    ButtonData:>{"ProtectNewSymbol.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\t",
  StyleBox[ButtonBox["$ProtectNewSymbols",
    ButtonData:>{"$ProtectNewSymbols.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  "\twhether to protect new symbol or not\n\[FilledSmallSquare] See: ",
  ButtonBox["Section 4.5",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ ]}, "xTensorRefGuide.nb", CharacterEncoding -> 
        "iso8859-1"], "Covariant derivatives"},
    ButtonStyle->"Hyperlink"],
  ".\n\[FilledSmallSquare] See also: ",
  StyleBox[ButtonBox["UndefCovD",
    ButtonData:>{"UndefCovD.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ".\n\[FilledSmallSquare] New in version 0.\n\[FilledSmallSquare] Last \
update: 23-IV-2011 for version 1.0.1 of ",
  StyleBox["xTensor`",
    FontFamily->"Courier"],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
ShowPageBreaks->False,
WindowSize->{574, 600},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingStartingPageNumber->4,
TaggingRules:>{"PaginationCache" -> {{2004, 11, 22, 16, 52, \
37.58997`8.327646958178029}, {4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, \
5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6}}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 29, 0, 38, "ObjectName"],
Cell[1808, 55, 869, 37, 64, "Usage"],
Cell[2680, 94, 3378, 107, 414, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

