(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6211,        211]*)
(*NotebookOutlinePosition[      6878,        234]*)
(*  CellTagsIndexPosition[      6834,        230]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["GiveSymbol", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["GiveSymbol[",
    FontFamily->"Courier"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier"],
  StyleBox["objects",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier"],
  " generates the symbol that will be used to identify the ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " associated to the sequence ",
  StyleBox["objects",
    FontSlant->"Italic"],
  "."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] The default behavior is just joining the symbols in \
the given order.\n\[FilledSmallSquare] With one object we currently have ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  ": ",
  StyleBox[ButtonBox["Tangent",
    ButtonData:>{"Tangent.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Christoffel",
    ButtonData:>{"Christoffel.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Torsion",
    ButtonData:>{"Torsion.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Riemann",
    ButtonData:>{"Riemann.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Ricci",
    ButtonData:>{"Ricci.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["TFRicci",
    ButtonData:>{"TFRicci.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["RicciScalar",
    ButtonData:>{"RicciScalar.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Einstein",
    ButtonData:>{"Einstein.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Weyl",
    ButtonData:>{"Weyl.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["epsilon",
    ButtonData:>{"epsilon.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", Inv, ",
  StyleBox[ButtonBox["ExtrinsicK",
    ButtonData:>{"ExtrinsicK.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Acceleration",
    ButtonData:>{"Acceleration.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["Projector",
    ButtonData:>{"Projector.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["AChristoffel",
    ButtonData:>{"AChristoffel.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox[ButtonBox["FRiemann",
    ButtonData:>{"FRiemann.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ". We also have ",
  StyleBox[ButtonBox["PD",
    ButtonData:>{"PD.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", ",
  StyleBox["etaUp",
    FontFamily->"Courier"],
  " and ",
  StyleBox["etaDown",
    FontFamily->"Courier"],
  " in ",
  StyleBox["xCoba`",
    FontFamily->"Courier"],
  ".\n\[FilledSmallSquare] With two objects we currently have: ",
  StyleBox[ButtonBox["Christoffel",
    ButtonData:>{"Christoffel.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  " and ",
  StyleBox[ButtonBox["AChristoffel",
    ButtonData:>{"AChristoffel.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ", and ",
  StyleBox[ButtonBox["Determinant",
    ButtonData:>{"Determinant.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ". Also ",
  StyleBox["Jacobian",
    FontFamily->"Courier"],
  " in ",
  StyleBox["xCoba`",
    FontFamily->"Courier"],
  ". \n\[FilledSmallSquare] See: ",
  ButtonBox["Section 1.4",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ ]}, "xTensorRefGuide.nb", CharacterEncoding -> 
        "iso8859-1"], "Relations among symbols"},
    ButtonStyle->"Hyperlink"],
  ".\n\[FilledSmallSquare] See also: ",
  StyleBox[ButtonBox["GiveOutputString",
    ButtonData:>{"GiveOutputString.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier"],
  ".\n\[FilledSmallSquare] New in version 0.\n\[FilledSmallSquare] Last \
update: 1-VII-2008 for version 0.9.6 of ",
  StyleBox["xTensor`",
    FontFamily->"Courier"],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 246}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 32, 0, 38, "ObjectName"],
Cell[1811, 55, 489, 19, 48, "Usage"],
Cell[2303, 76, 3892, 132, 232, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

